---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

**What happened?**

**What did you expect to happen?**

**Can you reproduce it?**
Ideally a small script that reproduces the problem

**Platform(please complete the following information):**
 - OS: [e.g. mac, windows, linux, arm or x86_64]
 - SASKTRAN2 version:
 - Installation Source: [e.g. conda, pip, or from source]

**Additional context**
Add any other context about the problem here.
